
Changelog
=========

0.1.0 (2017-06-21)
------------------

* First release on PyPI. (powered by cookiecutter-pylibrary_)

.. _cookiecutter-pylibrary: https://github.com/ionelmc/cookiecutter-pylibrary
